# ReportQuery

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**filter** | [**RawMessage**](RawMessage.md) |  | [optional] 
**group_by** | **list[str]** |  | [optional] 
**keys** | **list[str]** |  | [optional] 
**type** | **str** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


